@@ -1,14 +1,9 @@
 import os
 from copy import copy
-from concurrent.futures import ThreadPoolExecutor as Executor
-from pathlib import Path
 
-import click
 import xlsxwriter
-from filetype import guess
 
-from ..services.requests import extract_invoice, validation
-from .commons import read_pdf, InvoiceExtractorException
+from .commons import run_requests
 from .consts import RED_TO_GREEN_GRADIENT
 
 
@@ -37,76 +32,10 @@ def convert_to_xlsx(
         token {str} -- API token. (default: {None})
         workers {int} -- Amount of multithread. (default: {6})
     """
-    types = ("*.pdf", "*.tif", "*.tiff", "*.png", "*.jpg")
-    non_validation_cols = ("file_name", "row_number", "error_message")
-    file_count = 0
-    single_fieldnames = {
-        "file_name": (None, None, None),
-        "error_message": (None, None, None),
-    }
-    multi_fieldnames = {
-        "file_name": (None, None, None),
-        "row_number": (None, None, None),
-    }
-    result = {}
-
-    # TODO: Refactor this in seperate function, duplicate in csv.py
-    with Executor(max_workers=workers) as exe:
-        for file_type in types:
-            full_path = os.path.join(os.getcwd(), path)
-            files = Path(full_path).rglob(file_type)
-
-            # TODO: Put validation request inside of IE request job.
-            jobs = [
-                exe.submit(
-                    extract_invoice,
-                    read_pdf(str(filename)),
-                    extractor_endpoint,
-                    guess(str(filename)).mime,
-                    token,
-                )
-                for filename in files
-                if guess(str(filename)).mime
-            ]
-            label = f"Converting {len(jobs)} invoices with {file_type} extension"
-            with click.progressbar(jobs, label=label) as bar:
-                for id, job in enumerate(bar):
-                    file_path = None
-                    try:
-                        file_path, extracted_invoice = job.result(timeout=300)
-
-                        # TODO: Move this to extract_invoice function.
-                        if "error" in extracted_invoice["infos"]:
-                            error = extracted_invoice["infos"]["error"]
-                            raise InvoiceExtractorException(
-                                f"Error in Invoice Extractor: {error}"
-                            )
-
-                        if validation_endpoint:
-                            validated_invoice = validation(
-                                extracted_invoice, validation_endpoint
-                            )
-                        else:
-                            validated_invoice = None
-
-                        result[file_count] = flatten_invoice(
-                            extracted_invoice, validated_invoice,
-                        )
-                    except Exception as e:
-                        result[file_count] = {}
-                        result[file_count]["error_message"] = (repr(e), None, None)
-                    finally:
-                        file_name = file_path.split("/")[-1] if file_path else None
-                        result[file_count]["file_name"] = (file_name, None, None)
-
-                    collect_column_names(
-                        result[file_count], single_fieldnames, multi_fieldnames
-                    )
-
-                    file_count += 1
-
-    if not result:
-        quit(f"No files of extension: {types} found in path")
+    # Get requests result
+    result, single_fieldnames, multi_fieldnames, default_cols = run_requests(
+        workers, path, extractor_endpoint, validation_endpoint, token,
+    )
 
     # Structure result
     single_cardinality, multi_cardinality = structure_cardinality(
@@ -120,8 +49,8 @@ def convert_to_xlsx(
     workbook.add_worksheet("multi_cardinality")
 
     # Styling
-    bold_header = workbook.add_format({"bold": True})
-    red_to_green_formats = [
+    header = workbook.add_format({"bold": True})
+    probability_format = [
         workbook.add_format({"bold": True, "bg_color": color})
         for color in RED_TO_GREEN_GRADIENT
     ]
@@ -129,19 +58,19 @@ def convert_to_xlsx(
     write_single_cardinality(
         workbook,
         single_cardinality,
-        bold_header,
-        red_to_green_formats,
-        non_validation_cols,
-        validated_invoice,
+        header,
+        probability_format,
+        default_cols,
+        validation_endpoint,
     )
 
     write_multi_cardinality(
         workbook,
         multi_cardinality,
-        bold_header,
-        red_to_green_formats,
-        non_validation_cols,
-        validated_invoice,
+        header,
+        probability_format,
+        default_cols,
+        validation_endpoint,
     )
 
     workbook.close()
@@ -207,8 +136,8 @@ def write_single_cardinality(
     single_cardinality,
     bold_header,
     red_to_green_formats,
-    non_validation_cols,
-    validated_invoice,
+    default_cols,
+    validation_endpoint,
 ):
     """Write single cardinality items to workbook.
 
@@ -234,7 +163,7 @@ def write_single_cardinality(
             else:
                 worksheet.write(idx + 1, count, column_value)
 
-            if validated_invoice and key not in non_validation_cols:
+            if validation_endpoint and key not in default_cols:
                 validation_errors = validation_errors if validation_errors else 0
                 count += 1
                 worksheet.write(0, count, f"{key}ValidationErrors", bold_header)
@@ -252,8 +181,8 @@ def write_multi_cardinality(
     multi_cardinality,
     bold_header,
     red_to_green_formats,
-    non_validation_cols,
-    validated_invoice,
+    default_cols,
+    validation_endpoint,
 ):
     """Write multi cardinality items to workbook.
 
@@ -281,7 +210,7 @@ def write_multi_cardinality(
                 else:
                     worksheet.write(item_count, count, column_value)
 
-                if validated_invoice and key not in non_validation_cols:
+                if validation_endpoint and key not in default_cols:
                     validation_errors = validation_errors if validation_errors else 0
                     count += 1
                     worksheet.write(0, count, f"{key}ValidationErrors", bold_header)
